[Qa-jenkins-scm] [jenkins.debian.net] 02/02: reproducible: show previous status and build duration in schedule

Holger Levsen holger at moszumanska.debian.org
Fri Sep 18 11:24:51 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit f8aeea1c546391f54878fb305c65d35e17055569
Author: Holger Levsen <holger at layer-acht.org>
Date:   Fri Sep 18 13:24:41 2015 +0200

    reproducible: show previous status and build duration in schedule
---
 bin/reproducible_html_live_status.py | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index b60de0f..fb5ed69 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -32,7 +32,8 @@ def generate_schedule(arch):
     log.info('Building the schedule index page for ' + arch + '...')
     title = 'Packages currently scheduled on ' + arch + ' for testing for build reproducibility'
     query = 'SELECT sch.date_scheduled, s.suite, s.architecture, s.name ' + \
-            'FROM schedule AS sch JOIN sources AS s ON sch.package_id=s.id ' + \
+            'r.status, r.build_duration' + \
+            'FROM schedule AS sch JOIN sources AS s ON sch.package_id=s.id LEFT JOIN results AS r ON s.id=r.package_id ' + \
             'WHERE sch.date_build_started = "" AND s.architecture="{arch}" ORDER BY sch.date_scheduled'
     text = Template('$tot packages are currently scheduled for testing on $arch:')
     html = ''
@@ -44,12 +45,13 @@ def generate_schedule(arch):
     html += '<th>arch</th><th>source package</th></tr>\n'
     bugs = get_bugs()
     for row in rows:
         # 0: date_scheduled, 1: suite, 2: arch, 3: pkg name
         pkg = row[3]
+        duration = convert_into_hms_string(row[5])
         html += tab + '<tr><td> </td><td>' + row[0] + '</td>'
         html += '<td>' + row[1] + '</td><td>' + row[2] + '</td><td><code>'
         html += link_package(pkg, row[1], row[2], bugs)
-        html += '</code></td></tr>\n'
+        html += '</code></td><td>'+str(row[4])+'</td><td>'+duration+'</td></tr>\n'
     html += '</table></p>\n'
     destfile = BASE + '/index_' + arch + '_scheduled.html'
     desturl = REPRODUCIBLE_URL + '/index_' + arch + '_scheduled.html'
@@ -44,12 +45,13 @@ def generate_schedule(arch):
     bugs = get_bugs()
     for row in rows:
-        # 0: date_scheduled, 1: suite, 2: arch, 3: pkg name
+        # 0: date_scheduled, 1: suite, 2: arch, 3: pkg name 4: previous status 5: previous build duration
         pkg = row[3]

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list